# NAME
    c2y

# SYNOPSIS
    c2y <flags>

# DESCRIPTION
    Convert coco datasets to yolo datasets

# FLAGS
    -a, --ann_path=ANN_PATH
        Type: Optional[Optional]
        Default: None
    -i, --imgs_dir=IMGS_DIR
        Type: Optional[Optional]
        Default: None
    -y, --yolo_cfg_yaml=YOLO_CFG_YAML
        Type: Optional[Optional]
        Default: None
    -o, --output_dir=OUTPUT_DIR
        Type: Optional[Optional]
        Default: None
    -f, --force=FORCE
        Type: bool
        Default: False